macro_rules! assert_lengths_eq {
($a:expr, $b:expr) => { ... };
}Expand description
Assert the lengths of the two slices are equal.
macro_rules! assert_lengths_eq {
($a:expr, $b:expr) => { ... };
}Assert the lengths of the two slices are equal.