macro_rules! assert_size_and_alignment_eq {
($int:ty, $uint:ty) => { ... };
}Expand description
Ensure the two provided types have the same size and alignment.
macro_rules! assert_size_and_alignment_eq {
($int:ty, $uint:ty) => { ... };
}Ensure the two provided types have the same size and alignment.